// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KAMD_LOG_PLUGIN_LIBREOFFICE_EVENTSPY_DEBUGLIBREOFFICEEVENTSPY_H
#define ECM_QLOGGINGCATEGORY_KAMD_LOG_PLUGIN_LIBREOFFICE_EVENTSPY_DEBUGLIBREOFFICEEVENTSPY_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(KAMD_LOG_PLUGIN_LIBREOFFICE_EVENTSPY)


#endif
